pub struct RenderContext { /* private fields */ }
Represents data associated with rendering content.

Implementations

Create a new instance with a width and height.

Update the recorded width and height.

Get the width of the terminal window.

Get the height of the terminal window.

Is the terminal window width at least the minimal supported width.

Is the terminal window height at least the minimal supported height.

Is the terminal window large enough to render lines using their full width.

Is the terminal window too small to render content.