ViewDataUpdater

Struct ViewDataUpdater 

pub struct ViewDataUpdater<'view_data> { /* private fields */ }
An updater utility for a ViewData.

Implementations

Source

impl<'view_data> ViewDataUpdater<'view_data>

pub fn clear(&mut self)

Clear content of the view data.

pub fn clear_body(&mut self)

Clear just the body of the view data.

pub fn ensure_line_visible(&mut self, row_index: usize)

Set the line that must be visible during render.

pub fn ensure_column_visible(&mut self, column_index: usize)

Set the column to must be visible during render.

pub fn set_show_title(&mut self, show: bool)

Set if to show title.

pub fn set_show_help(&mut self, show: bool)

Set if to show help.

pub fn push_leading_line(&mut self, view_line: ViewLine)

Push a new leading line to the view data.

pub fn push_line(&mut self, view_line: ViewLine)

Push a new body line to the view data.

pub fn push_lines(&mut self, lines: &str)

Push a set of new body lines to the view data automatically split on newlines.

pub fn push_trailing_line(&mut self, view_line: ViewLine)

Push a new trailing line to the view data.

pub fn set_retain_scroll_position(&mut self, value: bool)

Set the scroll position retain value of the view data.

pub fn reset_scroll_position(&mut self)

Reset the scroll position of the view data.