pub struct ViewSender { /* private fields */ }
Represents a message sender and receiver for passing actions between threads.

Implementations

Create a new instance.

Clone the poisoned flag.

Is the sender poisoned, and not longer accepting actions.

Is the sender paused from refreshing the view.

Clone the render slice.

Queue a start action.

Errors

Results in an error if the sender has been closed.

Queue a stop action.

Errors

Results in an error if the sender has been closed.

Queue an end action.

Errors

Results in an error if the sender has been closed.

Queue a scroll up action.

Queue a scroll up action.

Queue a scroll up action.

Queue a scroll down action.

Queue a scroll left action.

Queue a scroll right action.

Queue a scroll up a page action.

Queue a scroll down a page action.

Queue a resize action.

Sync the ViewData and queue a render action.

Errors

Results in an error if the sender has been closed.