#[non_exhaustive]
pub struct TestContext { pub sender: ViewSender, pub receiver: Receiver<ViewAction>, }
Context for a ViewSender test.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
sender: ViewSender

The sender instance.

receiver: Receiver<ViewAction>

The receiver instance.

Implementations

Drop the receiver, useful for testing disconnect error handling.

Assert that render actions were sent.

Assert that certain messages were sent by the ViewSender.