Struct view::RenderContext
source · [−]pub struct RenderContext { /* private fields */ }Expand description
Represents data associated with rendering content.
Implementations
sourceimpl RenderContext
impl RenderContext
sourcepub const fn new(width: u16, height: u16) -> Self
pub const fn new(width: u16, height: u16) -> Self
Create a new instance with a width and height.
sourcepub const fn is_minimum_view_width(&self) -> bool
pub const fn is_minimum_view_width(&self) -> bool
Is the terminal window width at least the minimal supported width.
sourcepub const fn is_minimum_view_height(&self) -> bool
pub const fn is_minimum_view_height(&self) -> bool
Is the terminal window height at least the minimal supported height.
sourcepub const fn is_full_width(&self) -> bool
pub const fn is_full_width(&self) -> bool
Is the terminal window large enough to render lines using their full width.
sourcepub const fn is_window_too_small(&self) -> bool
pub const fn is_window_too_small(&self) -> bool
Is the terminal window too small to render content.