pub struct ViewDataUpdater<'view_data> { /* private fields */ }
An updater utility for a ViewData.

Implementations

Clear content of the view data.

Clear just the body of the view data.

Set the line that must be visible during render.

Set the column to must be visible during render.

Set if to show title.

Set if to show help.

Push a new leading line to the view data.

Push a new body line to the view data.

Push a set of new body lines to the view data automatically split on newlines.

Push a new trailing line to the view data.

Set the scroll position retain value of the view data.

Reset the scroll position of the view data.