Struct view::ViewDataUpdater
source · [−]pub struct ViewDataUpdater<'view_data> { /* private fields */ }Expand description
An updater utility for a ViewData.
Implementations
sourceimpl<'view_data> ViewDataUpdater<'view_data>
impl<'view_data> ViewDataUpdater<'view_data>
sourcepub fn clear_body(&mut self)
pub fn clear_body(&mut self)
Clear just the body of the view data.
sourcepub fn ensure_line_visible(&mut self, row_index: usize)
pub fn ensure_line_visible(&mut self, row_index: usize)
Set the line that must be visible during render.
sourcepub fn ensure_column_visible(&mut self, column_index: usize)
pub fn ensure_column_visible(&mut self, column_index: usize)
Set the column to must be visible during render.
sourcepub fn set_show_title(&mut self, show: bool)
pub fn set_show_title(&mut self, show: bool)
Set if to show title.
sourcepub fn set_show_help(&mut self, show: bool)
pub fn set_show_help(&mut self, show: bool)
Set if to show help.
sourcepub fn push_leading_line(&mut self, view_line: ViewLine)
pub fn push_leading_line(&mut self, view_line: ViewLine)
Push a new leading line to the view data.
sourcepub fn push_lines(&mut self, lines: &str)
pub fn push_lines(&mut self, lines: &str)
Push a set of new body lines to the view data automatically split on newlines.
sourcepub fn push_trailing_line(&mut self, view_line: ViewLine)
pub fn push_trailing_line(&mut self, view_line: ViewLine)
Push a new trailing line to the view data.
sourcepub fn set_retain_scroll_position(&mut self, value: bool)
pub fn set_retain_scroll_position(&mut self, value: bool)
Set the scroll position retain value of the view data.
sourcepub fn reset_scroll_position(&mut self)
pub fn reset_scroll_position(&mut self)
Reset the scroll position of the view data.