Struct view::ViewSender
source · [−]pub struct ViewSender { /* private fields */ }Expand description
Represents a message sender and receiver for passing actions between threads.
Implementations
sourceimpl Sender
impl Sender
sourcepub fn new(sender: Sender<ViewAction>) -> Self
pub fn new(sender: Sender<ViewAction>) -> Self
Create a new instance.
sourcepub fn clone_poisoned(&self) -> Arc<AtomicBool>
pub fn clone_poisoned(&self) -> Arc<AtomicBool>
Clone the poisoned flag.
sourcepub fn is_poisoned(&self) -> bool
pub fn is_poisoned(&self) -> bool
Is the sender poisoned, and not longer accepting actions.
sourcepub fn clone_render_slice(&self) -> Arc<Mutex<RenderSlice>>
pub fn clone_render_slice(&self) -> Arc<Mutex<RenderSlice>>
Clone the render slice.
sourcepub fn scroll_top(&self)
pub fn scroll_top(&self)
Queue a scroll up action.
sourcepub fn scroll_bottom(&self)
pub fn scroll_bottom(&self)
Queue a scroll up action.
sourcepub fn scroll_down(&self)
pub fn scroll_down(&self)
Queue a scroll down action.
sourcepub fn scroll_left(&self)
pub fn scroll_left(&self)
Queue a scroll left action.
sourcepub fn scroll_right(&self)
pub fn scroll_right(&self)
Queue a scroll right action.
sourcepub fn scroll_page_up(&self)
pub fn scroll_page_up(&self)
Queue a scroll up a page action.
sourcepub fn scroll_page_down(&self)
pub fn scroll_page_down(&self)
Queue a scroll down a page action.